<?php

/**
 * Message to New Members
 *
 * @author  emanuele
 * @license BSD http://opensource.org/licenses/BSD-3-Clause
 *
 * @version 0.0.2
 */

class MessageNewMembers_Integrate
{
	public static function modify_registration_settings(&$config_vars)
	{
		global $txt, $modSettings;

		loadLanguage('MessageNewMembers');

		$config_vars[] = '';
		$config_vars[] = array('check', 'send_pm_to_new');
		$config_vars[] = array('text', 'send_pm_to_new_subject');
		$config_vars[] = array('large_text', 'send_pm_to_new_body');
		$config_vars[] = array('text', 'send_pm_to_new_as');

		$existing = array();

		if (!empty($modSettings['send_pm_to_new_as']))
		{
			require_once(SUBSDIR . '/Members.subs.php');
			$id_members = array_map('intval', explode(',', $modSettings['send_pm_to_new_as']));
			$details = membersBy('member_ids', array('member_ids' => $id_members), true);
			foreach ($details as $member)
			{
				$existing[] = '
				{
					sItemId: ' . JavaScriptEscape($member['id_member']) . ',
					sItemName: ' . JavaScriptEscape($member['real_name']) . '
				}';
			}
		}

		loadJavascriptFile('suggest.js');
		addInlineJavascript('
		var oPmSendersSuggest = new smc_AutoSuggest({
			sSelf: \'oPmSendersSuggest\',
			sSessionId: elk_session_id,
			sSessionVar: elk_session_var,
			sSuggestId: \'pmSenders\',
			sControlId: \'send_pm_to_new_as\',
			sPostName: \'send_pm_to_new_as_list\',
			sSearchType: \'member\',
			bItemList: true,
			sTextDeleteItem: \'' . $txt['autosuggest_delete_item'] . '\',
			sURLMask: \'action=profile;u=%item_id%\',
			aListItems: [' . implode(",\n", $existing) . '
			]
		});', true);
	}

	public static function save_registration_settings()
	{
		$senders = array();
		if (class_exists('HttpReq'))
		{
			$request = HttpReq::instance();
		}
		else
		{
			require_once(SUBSDIR . '/MnmValuesBag.class.php');
			$request = new MnmValuesBag();
			$request->post = new MnmValuesBag($_POST);
		}

		if (empty($request->post->send_pm_to_new_as) && isset($request->post->send_pm_to_new_as_list))
		{
			$senders = array_filter(array_map('intval', $request->post->send_pm_to_new_as_list));
		}
		elseif (!empty($request->post->send_pm_to_new_as))
		{
			require_once(SUBSDIR . '/Members.subs.php');
			$members = array_map('Util::htmlspecialchars', explode(',', $request->post->send_pm_to_new_as));
			$senders = membersBy('member_names', array('member_names' => $members));
		}

		if (class_exists('HttpReq'))
			$request->post->send_pm_to_new_as = implode(',', $senders);
		else
			$_POST['send_pm_to_new_as'] = implode(',', $senders);


		$integration_function = !empty($_POST['send_pm_to_new']) ? 'add_integration_function' : 'remove_integration_function';

		$integration_function('integrate_activate', 'MessageNewMembers_Integrate::integrate_activate', 'SUBSDIR/MessageNewMembers.integrate.php');
	}

	public static function integrate_activate($member_name)
	{
		global $modSettings;

		require_once(SUBSDIR . '/Members.subs.php');
		$memberids = membersBy('member_names', array('member_names' => array($member_name)), false, false);
		$member_id = current($memberids);

		if (empty($modSettings['send_pm_to_new_as']))
		{
			$member_ids = array($member_id);
		}
		else
		{
			$send_pm_to_new_as = explode(',', $modSettings['send_pm_to_new_as']);
			$sender = $send_pm_to_new_as[array_rand($send_pm_to_new_as)];
			$member_ids = array($member_id, $sender);
		}

		$details = membersBy('member_ids', array('member_ids' => $member_ids), true);
		$newly_reg = $details[$member_id];
		$sender_data = $details[$sender];

		$replaces = array(
			'{member_name}' => $newly_reg['real_name'],
			'{profile_link}' => replaceBasicActionUrl('<a href="{script_url}?action=profile;u=') . $newly_reg['id_member'] . '">' . $newly_reg['real_name'] . '</a>',
			'{forum_name}' => replaceBasicActionUrl('{forum_name}'),
			'{forum_link}' => replaceBasicActionUrl('<a href="{script_url}">{forum_name}</a>'),
		);

		if (empty($modSettings['send_pm_to_new_as']))
		{
			$pm_from = null;
		}
		else
		{
			$pm_from = array(
				'id' => $sender_data['id_member'],
				'name' => $sender_data['real_name'],
				'username' => $sender_data['member_name']
			);
		}
		$body = strtr($modSettings['send_pm_to_new_body'], $replaces);

		require_once(SUBSDIR . '/PersonalMessage.subs.php');
		sendpm(array('to' => array($member_id), 'bcc' => array()), $modSettings['send_pm_to_new_subject'], $body, true, $pm_from);
	}
}